cis_config: /root/cis_interface/cis_interface/cis_interface/interface/PsiInterface.h Source File

cis_config

PsiInterface.h
1 #include <../tools.h>
2 #include <../communication/communication.h>
3 #include <../dataio/AsciiFile.h>
4 #include <../dataio/AsciiTable.h>
5 #include <CisInterface.h>
6
7 // Old, "psi" styled aliases
8
10 #ifndef PSIINTERFACE_H_
11 #define PSIINTERFACE_H_
12
14 #define psiInput_t cisInput_t
15 #define psiOutput_t cisOutput_t
16 #define psiInput cisInput
17 #define psiOutput cisOutput
18 #define psi_free cis_free
19 #define psi_input cisInput
20 #define psi_output cisOutput
21 #define psiInputFmt cisInputFmt
22 #define psiOutputFmt cisOutputFmt
23 #define psi_send cis_send
24 #define psi_recv cis_recv
25 #define psi_send_eof cis_send_eof
26 #define psi_send_nolimit cis_send_nolimit
27 #define psi_recv_nolimit cis_recv_nolimit
28 #define vpsiSend vcisSend
29 #define vpsiRecv vcisRecv
30 #define psiSend cisSend
31 #define psiRecv cisRecv
32 #define vpsiSend_nolimit vcisSend_nolimit
33 #define vpsiRecv_nolimit vcisRecv_nolimit
34 #define psiSend_nolimit cisSend_nolimit
35 #define psiRecv_nolimit cisRecv_nolimit
36 #define psiRpc_t cisRpc_t
37 #define psiRpc cisRpc
38 #define psiRpcClient cisRpcClient
39 #define psiRpcServer cisRpcServer
40 #define psi_free_rpc cis_free_rpc
41 #define psiAsciiFileInput_t cisAsciiFileInput_t
42 #define psiAsciiFileOutput_t cisAsciiFileOutput_t
43 #define psiAsciiFileInput cisAsciiFileInput
44 #define psiAsciiFileOutput cisAsciiFileOutput
45 #define psiAsciiTableInput_t cisAsciiTableInput_t
46 #define psiAsciiTableOutput_t cisAsciiTableOutput_t
47 #define psiAsciiTableInput cisAsciiTableInput
48 #define psiAsciiTableOutput cisAsciiTableOutput
49 #define psiAsciiTableInput_local cisAsciiTableInput_local
50 #define psiAsciiTableOutput_local cisAsciiTableOutput_local
51 #define psiAsciiArrayInput cisAsciiArrayInput
52 #define psiAsciiArrayOutput cisAsciiArrayOutput
53 #define psiAsciiArrayInput_local cisAsciiArrayInput_local
54 #define psiAsciiArrayOutput_local cisAsciiArrayOutput_local
55 #define psiPlyInput_t cisPlyInput_t
56 #define psiPlyOutput_t cisPlyOutput_t
57 #define psiPlyInput cisPlyInput
58 #define psiPlyOutput cisPlyOutput
59 #define psiObjInput_t cisObjInput_t
60 #define psiObjOutput_t cisObjOutput_t
61 #define psiObjInput cisObjInput
62 #define psiObjOutput cisObjOutput
63
64
65 #endif /*PSIINTERFACE_H_*/